@@ -37,6 +37,7 @@ from .paginator import (
 )
 from .type_defs import (
     ApiPassthroughTypeDef,
+    CertificateAuthorityConfigurationOutputTypeDef,
     CertificateAuthorityConfigurationTypeDef,
     CreateCertificateAuthorityAuditReportResponseTypeDef,
     CreateCertificateAuthorityResponseTypeDef,
@@ -137,7 +138,9 @@ class ACMPCAClient(BaseClient):
     def create_certificate_authority(
         self,
         *,
-        CertificateAuthorityConfiguration: CertificateAuthorityConfigurationTypeDef,
+        CertificateAuthorityConfiguration: Union[
+            CertificateAuthorityConfigurationTypeDef, CertificateAuthorityConfigurationOutputTypeDef
+        ],
         CertificateAuthorityType: CertificateAuthorityTypeType,
         RevocationConfiguration: RevocationConfigurationTypeDef = ...,
         IdempotencyToken: str = ...,
