@@ -81,6 +81,7 @@ __all__ = (
     "PutPolicyRequestRequestTypeDef",
     "RestoreCertificateAuthorityRequestRequestTypeDef",
     "RevokeCertificateRequestRequestTypeDef",
+    "ASN1SubjectOutputTypeDef",
     "ASN1SubjectTypeDef",
     "CreateCertificateAuthorityAuditReportResponseTypeDef",
     "CreateCertificateAuthorityResponseTypeDef",
@@ -103,13 +104,17 @@ __all__ = (
     "ListPermissionsResponseTypeDef",
     "RevocationConfigurationTypeDef",
     "PolicyQualifierInfoTypeDef",
+    "GeneralNameOutputTypeDef",
     "GeneralNameTypeDef",
     "UpdateCertificateAuthorityRequestRequestTypeDef",
     "PolicyInformationTypeDef",
+    "AccessDescriptionOutputTypeDef",
     "AccessDescriptionTypeDef",
     "ExtensionsTypeDef",
+    "CsrExtensionsOutputTypeDef",
     "CsrExtensionsTypeDef",
     "ApiPassthroughTypeDef",
+    "CertificateAuthorityConfigurationOutputTypeDef",
     "CertificateAuthorityConfigurationTypeDef",
     "IssueCertificateRequestRequestTypeDef",
     "CertificateAuthorityTypeDef",
@@ -555,6 +560,28 @@ RevokeCertificateRequestRequestTypeDef = TypedDict(
     },
 )
 
+ASN1SubjectOutputTypeDef = TypedDict(
+    "ASN1SubjectOutputTypeDef",
+    {
+        "Country": str,
+        "Organization": str,
+        "OrganizationalUnit": str,
+        "DistinguishedNameQualifier": str,
+        "State": str,
+        "CommonName": str,
+        "SerialNumber": str,
+        "Locality": str,
+        "Title": str,
+        "Surname": str,
+        "GivenName": str,
+        "Initials": str,
+        "Pseudonym": str,
+        "GenerationQualifier": str,
+        "CustomAttributes": List[CustomAttributeTypeDef],
+    },
+    total=False,
+)
+
 ASN1SubjectTypeDef = TypedDict(
     "ASN1SubjectTypeDef",
     {
@@ -825,6 +852,21 @@ PolicyQualifierInfoTypeDef = TypedDict(
     },
 )
 
+GeneralNameOutputTypeDef = TypedDict(
+    "GeneralNameOutputTypeDef",
+    {
+        "OtherName": OtherNameTypeDef,
+        "Rfc822Name": str,
+        "DnsName": str,
+        "DirectoryName": ASN1SubjectOutputTypeDef,
+        "EdiPartyName": EdiPartyNameTypeDef,
+        "UniformResourceIdentifier": str,
+        "IpAddress": str,
+        "RegisteredId": str,
+    },
+    total=False,
+)
+
 GeneralNameTypeDef = TypedDict(
     "GeneralNameTypeDef",
     {
@@ -884,6 +926,14 @@ class PolicyInformationTypeDef(
     pass
 
 
+AccessDescriptionOutputTypeDef = TypedDict(
+    "AccessDescriptionOutputTypeDef",
+    {
+        "AccessMethod": AccessMethodTypeDef,
+        "AccessLocation": GeneralNameOutputTypeDef,
+    },
+)
+
 AccessDescriptionTypeDef = TypedDict(
     "AccessDescriptionTypeDef",
     {
@@ -904,6 +954,15 @@ ExtensionsTypeDef = TypedDict(
     total=False,
 )
 
+CsrExtensionsOutputTypeDef = TypedDict(
+    "CsrExtensionsOutputTypeDef",
+    {
+        "KeyUsage": KeyUsageTypeDef,
+        "SubjectInformationAccess": List[AccessDescriptionOutputTypeDef],
+    },
+    total=False,
+)
+
 CsrExtensionsTypeDef = TypedDict(
     "CsrExtensionsTypeDef",
     {
@@ -922,6 +981,30 @@ ApiPassthroughTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredCertificateAuthorityConfigurationOutputTypeDef = TypedDict(
+    "_RequiredCertificateAuthorityConfigurationOutputTypeDef",
+    {
+        "KeyAlgorithm": KeyAlgorithmType,
+        "SigningAlgorithm": SigningAlgorithmType,
+        "Subject": ASN1SubjectOutputTypeDef,
+    },
+)
+_OptionalCertificateAuthorityConfigurationOutputTypeDef = TypedDict(
+    "_OptionalCertificateAuthorityConfigurationOutputTypeDef",
+    {
+        "CsrExtensions": CsrExtensionsOutputTypeDef,
+    },
+    total=False,
+)
+
+
+class CertificateAuthorityConfigurationOutputTypeDef(
+    _RequiredCertificateAuthorityConfigurationOutputTypeDef,
+    _OptionalCertificateAuthorityConfigurationOutputTypeDef,
+):
+    pass
+
+
 _RequiredCertificateAuthorityConfigurationTypeDef = TypedDict(
     "_RequiredCertificateAuthorityConfigurationTypeDef",
     {
@@ -986,7 +1069,7 @@ CertificateAuthorityTypeDef = TypedDict(
         "NotBefore": datetime,
         "NotAfter": datetime,
         "FailureReason": FailureReasonType,
-        "CertificateAuthorityConfiguration": CertificateAuthorityConfigurationTypeDef,
+        "CertificateAuthorityConfiguration": CertificateAuthorityConfigurationOutputTypeDef,
         "RevocationConfiguration": RevocationConfigurationTypeDef,
         "RestorableUntil": datetime,
         "KeyStorageSecurityStandard": KeyStorageSecurityStandardType,
